#! /usr/bin/perl
#
# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


use strict;
use warnings FATAL => 'all';
use diagnostics;


use Wanha::Cookie;
use Wanha::Session;
use Wanha::Link;
use Wanha::HTTP;
use Wanha::HTML;
use Wanha::Common;


=item print_settings
Print settings

0: sid
%: info
=cut
sub print_settings($\%) {
	my $sid = shift;
	my %info = %{shift()};

	my $self = &Wanha::Link::settings();
	my $p_reset = $info{'reset'} == 1 ? " CHECKED" : "";
	my $p_count = $info{'urls'};
	my $p_age = int($info{'age'} / 24 / 60 / 60);

	my $l_title = &Wanha::Lang::get("settings-title");
	my $l_reset = &Wanha::Lang::get("settings-reset");
	my $l_count = &Wanha::Lang::get("settings-count");
	my $l_age = &Wanha::Lang::get("settings-age");
	my $l_ok = &Wanha::Lang::get("settings-save");

	print <<EOF;
<h1>$l_title</h1>

<form method="post" action="$self">
<input type="hidden" name="set" value="1" />
<table>
	<tr>
		<th>Automatic reset</th>
		<td><input type="checkbox" name="reset"$p_reset /></td>
	</tr>
	<tr>
		<th>Max URL-count</th>
		<td><input type="text" name="count" size="8"
				value="$p_count" /></td>
	</tr>
	<tr>
		<th>Cookie age<br />(days)</th>
		<td><input type="text" name="age" size="8"
				value="$p_age" /></td>
	</tr>
	<tr>
		<td colspan="2">
			<input type="submit" value="$l_ok" />
		</td>
	</tr>
</table>
</form>
EOF
}


=item set_settings
Set settings

0: sid
1: latest url id
2: cookie age
3: max count
4: cookie set date
5: auto reset
=cut
sub set_settings($$$$$$) {
	my ($sid, $old_latest_id, $old_age, $old_count,
			$old_set, $old_reset) = @_;

	my $new_age = &Wanha::HTTP::post_numeric("age", 0);
	my $new_count = &Wanha::HTTP::post_numeric("count", $old_count);
	my $new_reset = &Wanha::HTTP::post("reset", $old_reset);

	if ($new_age == 0) {
		$new_age = $old_age;
	} else {
		$new_age *= 24 * 60 * 60;
	}
	$new_reset = ($new_reset =~ /^on$/i) ? 1 : 0;

	&Wanha::Cookie::save_settings($sid, $new_age, $new_count, $new_reset);
	&Wanha::Cookie::update_set_date($sid);
}


=item main
Main function
=cut
sub main() {
	my $sid;
	my $phase;

	# Updates cookie automagically
	$sid = &Wanha::Session::get_id();
	&Wanha::Session::check_sid($sid,
			&Wanha::Link::session(1, &Wanha::Link::settings()));

	my %info = &Wanha::Cookie::get_info($sid);

#	my ($old_url_id, $old_age, $old_count, $old_date, $old_reset) =
#			&Session::get_settings($sid);

	if (&Wanha::HTTP::post_numeric("set", 0) == 1) {
		&set_settings($sid, $info{'latest'}, $info{'age'},
				$info{'visits'}, $info{'set'},
				$info{'reset'});
		&Wanha::Cookie::update_set_date($sid);
		%info = &Wanha::Cookie::get_info($sid);
	}

	&Wanha::HTTP::print_header();
	&Wanha::HTML::print_header();

	&Wanha::Session::print_links();

	&print_settings($sid, \%info);
	if (&Wanha::HTTP::post_numeric("set", 0) == 1) {
		&Wanha::Lang::printf("<p><em><&settings-updated&></em></p>\n");
	}

	&Wanha::HTML::print_footer(&Wanha::Common::process_time());
}


&main();
exit(0);
